@@ -1,7 +1,10 @@
 PY_ENVIRONMENT_HELP = """
 The path to the virtualenv where your python dependencies for your code are installed
 """
-PY_RUN_HELP = """The command you would like to run to run your code. Put the command in between quotes "gunicorn main:app" """
+STARTUP_COMMAND_HELP = """
+The command you would like to run in order to run 
+your code. Put the command in between quotes "gunicorn main:app"
+"""
 
 JAVASCRIPT_DIRECTORY_HELP = """
 The path to the directory where your javascript code should be stored in a file and run
